.. image:: docs/_static/logo.png

|


**OGGM is a modular open source model for glacier dynamics**

OGGM is able to simulate past and
future mass balance, volume and geometry of (almost) any glacier in the world,
in a fully automated and extensible workflow.

The model accounts for glacier geometry (including contributory branches) and
includes an explicit ice dynamics module. We rely exclusively on publicly
available data for calibration and validation. **OGGM is modular and
supports novel modelling workflows**: it LOVES to be remixed and reused!

.. image:: docs/_static/ex_tasman.jpg


Installation, documentation
---------------------------

The documentation is hosted on ReadTheDocs: http://docs.oggm.org


Get in touch
------------

- View the source code `on GitHub`_.
- Report bugs or share your ideas on the `issue tracker`_.
- Improve the model by submitting a `pull request`_.
- Or you can always send us an `e-mail`_ the good old way.

.. _e-mail: info@oggm.org
.. _on GitHub: https://github.com/OGGM/oggm
.. _issue tracker: https://github.com/OGGM/oggm/issues
.. _pull request: https://github.com/OGGM/oggm/pulls


About
-----

:Version:
    .. image:: https://img.shields.io/pypi/v/oggm.svg
        :target: https://pypi.python.org/pypi/oggm
        :alt: Pypi version

    .. image:: https://img.shields.io/pypi/pyversions/oggm.svg
        :target: https://pypi.python.org/pypi/oggm
        :alt: Supported python versions

:Citation:
    .. image:: https://img.shields.io/badge/Citation-GMD%20paper-orange.svg
        :target: https://www.geosci-model-dev.net/12/909/2019/
        :alt: GMD Paper

    .. image:: https://img.shields.io/badge/DOI-10.5281%2Fzenodo.597193-blue.svg
        :target: https://zenodo.org/doi/10.5281/zenodo.597193
        :alt: Zenodo

:Tests:
    .. image:: https://coveralls.io/repos/github/OGGM/oggm/badge.svg?branch=master
        :target: https://coveralls.io/github/OGGM/oggm?branch=master
        :alt: Code coverage

    .. image:: https://github.com/OGGM/oggm/actions/workflows/run-tests.yml/badge.svg?branch=master
        :target: https://github.com/OGGM/oggm/actions/workflows/run-tests.yml
        :alt: Linux build status

    .. image:: https://readthedocs.org/projects/oggm/badge/?version=latest
        :target: http://docs.oggm.org/en/latest/
        :alt: Documentation status

:License:
    .. image:: https://img.shields.io/pypi/l/oggm.svg
        :target: https://github.com/OGGM/oggm/blob/master/LICENSE.txt
        :alt: BSD-3-Clause License

:Authors:

    See the `version history`_ for a list of all contributors.

    .. _version history: http://docs.oggm.org/en/stable/whats-new.html
